@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2022  Błażej Szczygieł
+    Copyright (C) 2010-2023  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -60,7 +60,7 @@ Updater::Updater(QObject *parent) :
     connect(installB, SIGNAL(clicked()), this, SLOT(applyUpdate()));
 
     QVBoxLayout *layout = new QVBoxLayout(this);
-    layout->setMargin(2);
+    layout->setContentsMargins(2, 2, 2, 2);
     layout->addWidget(infoL);
     layout->addWidget(downloadUpdateB);
     layout->addWidget(progressB);
