@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2022  Błażej Szczygieł
+    Copyright (C) 2010-2023  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -20,8 +20,6 @@
 
 #include <FFDecHWAccel.hpp>
 
-struct SwsContext;
-
 class FFDecVTB final : public FFDecHWAccel
 {
 public:
@@ -32,11 +30,8 @@ public:
 
     QString name() const override;
 
-    void downloadVideoFrame(Frame &decoded) override;
-
     bool open(StreamInfo &streamInfo) override;
 
 private:
     AVBufferRef *m_hwDeviceBufferRef = nullptr;
-    SwsContext *m_swsCtx = nullptr;
 };
