@@ -46,6 +46,8 @@ private:
     void init();
 
 public:
+    inline shared_ptr<Queue> queue() const;
+
     void storeData(
         const MemoryObjectDescrs &memoryObjects,
         const shared_ptr<DescriptorSet> &descriptorSet
@@ -76,4 +78,11 @@ private:
     bool m_resetNeeded = false;
 };
 
+/* Inline implementation */
+
+shared_ptr<Queue> CommandBuffer::queue() const
+{
+    return m_queue;
+}
+
 }
